Interactive time series figures in AAS journals
===============================================

About
-----

The **aas-timeseries** package has been developed as part of a project between
`AAS Publishing <https://journals.aas.org/>`_ and the `Astropy Project
<http://www.astropy.org>`_. The goal of this project is to provide astronomers
with all the tools needed to make it possible for astronomers to read in and
manipulate time series in Astropy, produce interactive figures, and easily embed
these in a paper. The package is general enough to be usable in other contexts,
for example to embed interactive time series figures in personal web pages,
or for use in Jupyter notebooks and Jupyter Lab.

If you run into any issues or would like to request features, please head over
to our `issue tracker
<https://github.com/aperiosoftware/aas-timeseries/issues>`_.

User guide
----------

.. toctree::
   :maxdepth: 1

   installing
   getting_started
   layers
   views
   tooltips
   timeaxes
   saving
   submitting
   api
